| Title: | Connect to the 'jamovi' Statistical Spreadsheet |
|---|---|
| Description: | Methods to access data sets from the 'jamovi' statistical spreadsheet (see <https://www.jamovi.org> for more information) from R. |
| Authors: | Jonathon Love [aut, cre] |
| Maintainer: | Jonathon Love <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.5.7 |
| Built: | 2026-05-20 10:21:01 UTC |
| Source: | https://github.com/cran/jmvconnect |
Reads a data set from jamovi
read(id, columns)read(id, columns)
id |
the number, or the title of the data set to read |
columns |
(optional) only reads the columns named |
the data set as a data frame
## Not run: jmvconnect::what() # Available Data Sets # ------------------------------------- # Title Rows Cols # ------------------------------------- # 1 iris 150 5 # 2 Tooth Growth 60 3 # ------------------------------------- data <- jmvconnect::read('Tooth Growth') # or data <- jmvconnect::read(2) ## End(Not run)## Not run: jmvconnect::what() # Available Data Sets # ------------------------------------- # Title Rows Cols # ------------------------------------- # 1 iris 150 5 # 2 Tooth Growth 60 3 # ------------------------------------- data <- jmvconnect::read('Tooth Growth') # or data <- jmvconnect::read(2) ## End(Not run)
Lists the data sets available from jamovi. Data sets can then be read using the read() function.
what()what()
## Not run: jmvconnect::what() # Available Data Sets # ------------------------------------- # Title Rows Cols # ------------------------------------- # 1 iris 150 5 # 2 Tooth Growth 60 3 # ------------------------------------- data <- jmvconnect::read('Tooth Growth') # or data <- jmvconnect::read(2) ## End(Not run)## Not run: jmvconnect::what() # Available Data Sets # ------------------------------------- # Title Rows Cols # ------------------------------------- # 1 iris 150 5 # 2 Tooth Growth 60 3 # ------------------------------------- data <- jmvconnect::read('Tooth Growth') # or data <- jmvconnect::read(2) ## End(Not run)